@@ -395,7 +395,7 @@ parse_args (int *argc, char ***argv)
         gnome_settings_profile_end (NULL);
 
         if (debug)
-                g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
+                g_setenv ("G_MESSAGES_DEBUG", "all", FALSE);
 }
 
 int
